@@ -3,7 +3,7 @@ package WWW::Google::Time;
 use warnings;
 use strict;
 
-our $VERSION = '0.0115';
+our $VERSION = '0.0116';
 
 use LWP::UserAgent;
 use URI;
@@ -61,12 +61,15 @@ sub get_time {
 # <b>Time</b> in <b>Toronto</b>, Ontario</table>
 @data{ qw/time day_of_week time_zone where/ } = $response->content
 
-    =~ m{<img \s+ src="/images/icons/onebox/clock-40[.]gif[^>]*><td \s+ valign=(?:top|middle)><em>([^<]+)<\/em> \s+ (\S+) \s+ \( (\w+) \) \s+ -
-\s+ <em>Time<\/em>
+    =~ m{<td valign="?(?:top|middle)"?><em>([^<]+)<\/em> (\S+) \((\w+)\) - <em>Time<\/em> in (.+?)<(?:\/table|br)>}
 
-        \s+ in \s+ (.+?)<(?:br|/table)>
-
-    }x or do {
+    or do {
+#     =~ m{<img \s+ src="/images/icons/onebox/clock-40[.]gif[^>]*><td \s+ valign=(?:top|middle)><em>([^<]+)<\/em> \s+ (\S+) \s+ \( (\w+) \) \s+ -
+# \s+ <em>Time<\/em>
+# 
+#         \s+ in \s+ (.+?)<(?:br|/table)>
+# 
+#     }x or do {
 #         print "\n\n\n" . $response->content . "\n\n\n";
         return $self->_set_error("Could not find time data for that location");
     };
@@ -229,7 +232,7 @@ Would be nice to be able to return all three results in an arrayref or something
 Zoffix Znet, C<< <zoffix at cpan.org> >>
 (L<http://zoffix.com/>, L<http://haslayout.net/>, L<http://zofdesign.com/>)
 
-Patches by Neil Stott and Zach Hauri
+Patches by Neil Stott and Zach Hauri (L<http://zach.livejournal.com/>)
 
 =head1 BUGS
 
